<!DOCTYPE html>


<h2>Fast and secure method for software development.</h2>

<h1></h1>

<h4>This framework is for General purpose software development.</h4>
<h4>By using this framework , you will reduce the size of you code significantly.</h4>

<p></p>

<p></p>


<h3>Advantages:</h3>
<h4>Simple, Fast and Secure method to create robust software with less code</h4>
<ul>
    <li>Attributes already created for you.</strong></li>
    <li>Methods already created for you.</strong></li>
    <li>Classes already created for you.</strong></li>
    <li>Descriptors already created for you.</strong></li>
    <li>Metaclasses already created for you.</strong></li>
    <li>Decorators already created for you.</strong></li>
</ul>

<h1></h1>

<p>How to use the framework.</p>

<h3>Example:</h3>
<ol>
    <li>"pip install yetu" in your machine</li>
    <li>from yetu.person.classes import person</strong></li>
    <li>user1 = person.PersonMethods().</strong></li>
    <li> user1.set_first_name("David")</strong></li>
    <li> user1.set_last_name("Johnnes")</strong></li>
    <li> user1.show_first_name()</strong></li>
    <li> user1.show_last_name()</strong></li>
    <li>OR:</strong></li>
    <li>from yetu.person.decorators</strong></li>
    <li>from yetu.person.descriptors</strong></li>
    <li>from yetu.person.metas</strong></li>
    <li>You have the flexibility to subclass the classes/metas.</strong></li>
</ol>

<p></p>

<h1></h1>


<p>You can contact: david.johnnes@gmail.com.</p>

<h1></h1>


